@@ -2,7 +2,7 @@
 # Run: mpiexec -np 4 Rscript iris_dmat.r
 
 rm(list = ls())                                       # Clean environment
-library(pbdDMAT, quiet = TRUE)                        # Load library
+library(pbdDMAT, quietly = TRUE)                      # Load library
 init.grid()
 
 ### Load data
@@ -16,7 +16,7 @@ X.dmat <- as.ddmatrix(X)
 X.std <- scale(X.dmat)
 
 ### Clustering
-library(pmclust, quiet = TRUE)
+library(pmclust, quietly = TRUE)
 comm.set.seed(123, diff = TRUE)
 
 X.dmat <- X.std
