@@ -2,7 +2,7 @@
 # Run: mpiexec -np 4 Rscript iris_dmat.r
 
 rm(list = ls())                                       # Clean environment
-library(pbdDMAT, quiet = TRUE)                        # Load library
+library(pbdDMAT, quietly = TRUE)                      # Load library
 init.grid()
 if(comm.size() >= 150)
   comm.stop("Too many processors.")
@@ -20,7 +20,7 @@ jid <- get.jid(nrow(X.std))
 X.std <- X.std[jid,]
 
 ### Clustering
-library(pmclust, quiet = TRUE)
+library(pmclust, quietly = TRUE)
 comm.set.seed(123, diff = TRUE)
 
 X.spmd <- X.std
